@@ -2,19 +2,23 @@ import sys, os, logging
 import gtk, gobject
 from sugar.activity import activity
 
+import hulahop
+
 #need to set things up before we import penguintv
 
+activity_root = activity.get_bundle_path()
+	
+#chdir here so that relative RPATHs line up ('./lib')
+os.chdir(activity_root) 
+	
+#append to sys.path for the python packages
+sys.path = [activity_root,] + sys.path
+
 try:
 	import pycurl
 except:
 	logging.warning("Trying to load bundled pycurl libraries")
 	
-	#where are we?
-	activity_root = activity.get_bundle_path()
-	
-	#chdir here so that relative RPATHs line up ('./lib')
-	os.chdir(activity_root) 
-	
 	#append to sys.path for the python packages
 	sys.path.append(os.path.join(activity_root, 'site-packages'))
 	
@@ -29,12 +33,24 @@ class PenguinTVActivity(activity.Activity):
 		activity.Activity.__init__(self, handle)
 		app = penguintv.PenguinTVApp(self)
 		self.set_title('News Reader')
+		toolbox = activity.ActivityToolbox(self)
+		
+		#toolbox.add_toolbar(_('Feeds'), app.main_window.toolbar)
+		app.connect('app-loaded', self.add_toolbar, toolbox)
+		#gobject.idle_add(self.add_toolbar, toolbox, app)
+		
+		self.set_toolbox(toolbox)
+		toolbox.show()
 		self.connect('destroy',self.do_quit, app)
 	
 	def do_quit(self, event, app):
 		app.do_quit()
 		logging.info('deleting app now')
 		del app
+		
+	def add_toolbar(self, app, toolbox):
+		toolbox.add_toolbar(_('Feeds'), app.main_window.toolbar)
+		
 
 if __name__ == '__main__': # Here starts the dynamic part of the program
 
