@@ -17,7 +17,8 @@ import HTMLParser
 import utils
 import AddFeedUtils
 from ptvDB import FF_NOAUTODOWNLOAD, FF_NOSEARCH, FF_NOAUTOEXPIRE, \
-                  FF_NOTIFYUPDATES, FF_ADDNEWLINES, FF_MARKASREAD
+                  FF_NOTIFYUPDATES, FF_ADDNEWLINES, FF_MARKASREAD, \
+                  FF_NOKEEPDELETED
 import LoginDialog
 if utils.HAS_PYXML:
 	import itunes
@@ -44,9 +45,6 @@ class AddFeedDialog:
 			self._feed_url_widget = combo.child
 			combo.connect('changed', self.on_sugar_combo_changed)
 			self._edit_tags_widget = None
-			
-		if utils.RUNNING_HILDON:
-			self._hildon_inited = False
 		
 	def extract_content(self):
 		box = self._xml.get_widget('add_feed_box')
@@ -58,30 +56,9 @@ class AddFeedDialog:
 				
 	def show(self, autolocation=True):
 		if utils.RUNNING_HILDON:
-			if not self._hildon_inited:
-				#put in a scrolled viewport so the user can see all the prefs
-				parent = self._xml.get_widget('tab1_container')
-				contents = self._xml.get_widget('tab1_contents')
-				scrolled = gtk.ScrolledWindow()
-				scrolled.set_size_request(650, 200)
-				scrolled.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-				viewport = gtk.Viewport()
-				contents.reparent(viewport)
-				scrolled.add(viewport)
-				parent.add(scrolled)
-				
-				parent = self._xml.get_widget('tab2_container')
-				contents = self._xml.get_widget('tab2_contents')
-				scrolled = gtk.ScrolledWindow()
-				scrolled.set_size_request(650, 200)
-				scrolled.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-				viewport = gtk.Viewport()
-				contents.reparent(viewport)
-				scrolled.add(viewport)
-				parent.add(scrolled)
-				self._hildon_inited = True
+			self._window.resize(650,300)
 			self._window.show_all()
-	
+			
 		self._feed_url_widget.grab_focus()
 		if self._window:
 			self._window.show()
@@ -97,15 +74,16 @@ class AddFeedDialog:
 			
 		if not utils.HAS_SEARCH:
 			self._xml.get_widget('b_search').hide()
-		if utils.RUNNING_SUGAR:
+		if utils.RUNNING_SUGAR or not utils.HAS_STATUS_ICON:
 			self._xml.get_widget('b_notifyupdates').hide()
 	
 	#ripped from straw
 	def set_location_automatically(self):
 		def _clipboard_cb(cboard, text, data=None):
-			if text.upper().startswith("FEED:") or \
-			   text.upper().startswith("HTTP"):
-				self._feed_url_widget.set_text(text)
+			if text:
+				if text.upper().startswith("FEED:") or \
+				   text.upper().startswith("HTTP"):
+					self._feed_url_widget.set_text(text)
 					        	
 		clipboard = gtk.clipboard_get(selection="CLIPBOARD")
 		clipboard.request_text(_clipboard_cb, None)
@@ -157,6 +135,8 @@ class AddFeedDialog:
 				flags += FF_ADDNEWLINES
 			if self._xml.get_widget('b_markasread').get_active():
 				flags += FF_MARKASREAD
+			if self._xml.get_widget('b_nokeepdeleted').get_active():
+				flags += FF_NOKEEPDELETED
 	
 		tags=[]
 		if len(self._edit_tags_widget.get_text()) > 0:
@@ -168,7 +148,9 @@ class AddFeedDialog:
 		while gtk.events_pending(): #make sure the sensitivity change goes through
 			gtk.main_iteration()
 		try:
-			url,title = AddFeedUtils.correct_url(url, self._app.glade_prefix)
+			logging.debug("getting corrected url:")
+			url,title = AddFeedUtils.correct_url(url, utils.get_glade_prefix())
+			logging.debug("got: %s %s" % (url, title))
 			if url is None:
 				if self._window:
 					self._window.set_sensitive(True)
@@ -212,6 +194,22 @@ class AddFeedDialog:
 			return #don't hide, give them a chance to try again.
 		
 		self.hide()
+		
+	def on_help_button_clicked(self, event):
+ 		dialog = gtk.Dialog(title=_("Add Feed Help"), parent=None, flags=gtk.DIALOG_MODAL, buttons=(gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+		hbox = gtk.HBox()
+		hbox.set_spacing(12)
+		image = gtk.image_new_from_stock(gtk.STOCK_DIALOG_INFO, gtk.ICON_SIZE_DIALOG)
+		hbox.pack_start(image, False, False, 12)
+		label = gtk.Label(_("""Please enter the URL of the feed you would like to add.  Also enter any tags you would like to apply to this feed, separated by commas"""))
+		label.set_line_wrap(True)
+		hbox.pack_start(label, True, True, 0)
+		dialog.vbox.pack_start(hbox, True, True, 0)
+		dialog.show_all()
+		dialog.resize(400,-1)
+		response = dialog.run()
+		dialog.hide()
+		del dialog
 				
 	def on_button_ok_clicked(self,event):
 		self.finish()
