@@ -39,17 +39,18 @@ class EntryList(gobject.GObject):
                            ([gobject.TYPE_INT]))
     }	
 	
-	def __init__(self, widget_tree, app, feed_list_view, main_window, db):
+	def __init__(self, widget_tree, app, feed_list_view, main_window):
 		gobject.GObject.__init__(self)
 		self._widget = widget_tree.get_widget("entrylistview")
 		self._main_window = main_window
 		self._entrylist = gtk.ListStore(str, str, int, int, str, int, int, bool) #title, markeduptitle, entry_id, index, icon, flag, feed, visible
-		self._db = db
+		self._app = app
 		self._feed_id=None
 		self._last_entry=None
 		self._search_query = ""
 		self._search_results = []
 		self._state = S_DEFAULT
+		self._hide_viewed = False
 		self.__populating = False
 		self.__cancel_populating = False
 		self.presently_selecting = False
@@ -132,7 +133,8 @@ class EntryList(gobject.GObject):
 			self.populate_entries(None)
 		
 	def __feed_polled_cb(self, app, feed_id, update_data):
-		if feed_id == self._feed_id:
+		feed_list = self._app.db.get_associated_feeds(feed_id)
+		if self._feed_id in feed_list:
 			self.update_entry_list()
 			
 	def __feed_removed_cb(self, app, feed_id):
@@ -144,10 +146,11 @@ class EntryList(gobject.GObject):
 		
 	def __entries_viewed_cb(self, app, viewlist):
 		for feed_id, entrylist in viewlist:
-			if feed_id == self._feed_id:
+			feed_list = self._app.db.get_associated_feeds(feed_id)
+			if self._feed_id in feed_list:
 				for e in entrylist:
 					self.update_entry_list(e)
-			
+					
 	def populate_if_selected(self, feed_id):
 		if feed_id == self._feed_id:
 			self.populate_entries(feed_id, -1)
@@ -171,7 +174,11 @@ class EntryList(gobject.GObject):
 			dont_autopane = False #it's a double negative, but it makes sense to me at the moment.
 		self._feed_id = feed_id
 		
-		db_entrylist = self._db.get_entrylist(feed_id)
+		
+		db_entrylist = self._app.db.get_entrylist(feed_id)
+		if self._hide_viewed:
+			unviewed = self._app.db.get_unread_entries(feed_id)
+			db_entrylist = [e for e in db_entrylist if e[0] in unviewed]
 		selection = self._widget.get_selection()
 		if selected==-1:
 			rows = selection.get_selected_rows()
@@ -194,7 +201,7 @@ class EntryList(gobject.GObject):
 					self.__cancel_populating = False
 					break
 				i=i+1	
-				flag = self._db.get_entry_flag(entry_id)
+				flag = self._app.db.get_entry_flag(entry_id)
 				icon = self._get_icon(flag)
 				markeduptitle = self._get_markedup_title(title, flag)
 				self._entrylist.append([title, markeduptitle, entry_id, i, icon, flag, feed_id, True])
@@ -263,11 +270,11 @@ class EntryList(gobject.GObject):
 		
 	def update_entry_list(self, entry_id=None):
 		if entry_id is None:
-			if len(self._entrylist) != len(self._db.get_entrylist(self._feed_id)):
+			if len(self._entrylist) != len(self._app.db.get_entrylist(self._feed_id)):
 				self.populate_entries(self._feed_id)
 				return
 			for entry in self._entrylist:
-				entry[FLAG] = self._db.get_entry_flag(entry[ENTRY_ID])
+				entry[FLAG] = self._app.db.get_entry_flag(entry[ENTRY_ID])
 		 		entry[MARKEDUPTITLE] = self._get_markedup_title(entry[TITLE],entry[FLAG])
 		 		entry[ICON] = self._get_icon(entry[FLAG]) 
 		else:
@@ -275,7 +282,7 @@ class EntryList(gobject.GObject):
 				index = self.find_index_of_item(entry_id)
 				if index is not None:
 					entry = self._entrylist[index]
-					entry[FLAG] = self._db.get_entry_flag(entry_id)
+					entry[FLAG] = self._app.db.get_entry_flag(entry_id)
 				 	entry[MARKEDUPTITLE] = self._get_markedup_title(entry[TITLE],entry[FLAG])
 					entry[ICON] = self._get_icon(entry[FLAG]) 
 				else:
@@ -306,16 +313,20 @@ class EntryList(gobject.GObject):
 		if len(entries) == 0:
 			self.emit('no-entry-selected')
 			return
+			
+		self._hide_viewed = False
+		self._main_window.set_hide_entries_menuitem(self._hide_viewed)
+		self._main_window.set_hide_entries_visibility(False)
 		
 		i=-1
 
 		for entry_id,title, fakedate, feed_id in entries:	
 			i+=1
 			try:
-				entry = self._db.get_entry(entry_id)
+				entry = self._app.db.get_entry(entry_id)
 			except ptvDB.NoEntry:
 				raise ptvDB.BadSearchResults, "Entry not found, possible out of date index"
-			flag = self._db.get_entry_flag(entry_id)
+			flag = self._app.db.get_entry_flag(entry_id)
 			icon = self._get_icon(flag)
 			markeduptitle = self._get_markedup_title(entry['title'], flag)
 			self._entrylist.append([entry['title'], markeduptitle, entry_id, i, icon, flag, feed_id, True])
@@ -416,7 +427,7 @@ class EntryList(gobject.GObject):
 	def on_row_activated(self, treeview, path, view_column):
 		index = path[0]
 		model = treeview.get_model()
-		item = self._db.get_entry(model[index][ENTRY_ID])
+		item = self._app.db.get_entry(model[index][ENTRY_ID])
 		self.emit('link-activated', item['link'])
 		
 	def do_context_menu(self, event):
@@ -466,7 +477,7 @@ class EntryList(gobject.GObject):
 			item.connect('activate',self._main_window.on_mark_entry_as_unviewed_activate)
 			menu.append(item)
 			
-		keep = self._db.get_entry_keep(selected['entry_id'])
+		keep = self._app.db.get_entry_keep(selected['entry_id'])
 		if keep:
 			item = gtk.MenuItem(_("_Don't Keep New"))
 			item.connect('activate',self._main_window.on_unkeep_entry_new_activate)
@@ -476,5 +487,29 @@ class EntryList(gobject.GObject):
 			item.connect('activate',self._main_window.on_keep_entry_new_activate)
 			menu.append(item)
 			
+		if self._state != S_SEARCH:
+			if self._hide_viewed:
+				item = gtk.MenuItem(_("_Show All"))
+				item.connect('activate', self._toggle_hide_viewed)
+				menu.append(item)
+			else:
+				item = gtk.MenuItem(_("_Hide Viewed Entries"))
+				item.connect('activate', self._toggle_hide_viewed)
+				menu.append(item)
+			
 		menu.show_all()
 		menu.popup(None,None,None, event.button,event.time)
+		
+	def set_hide_viewed(self, state):
+		if state == self._hide_viewed:
+			return
+				
+		self._toggle_hide_viewed()
+		
+	def _toggle_hide_viewed(self, e=None):
+		if self._hide_viewed:
+			self._hide_viewed = False
+		else:
+			self._hide_viewed = True
+		self._main_window.set_hide_entries_menuitem(self._hide_viewed)
+		self.populate_entries(self._feed_id)
