@@ -5,7 +5,7 @@ import penguintv
 import utils
 from ptvDB import FeedAlreadyExists, FF_NOAUTODOWNLOAD, FF_NOSEARCH, \
 				  FF_NOAUTOEXPIRE, FF_NOTIFYUPDATES, FF_ADDNEWLINES, \
-				  FF_MARKASREAD 
+				  FF_MARKASREAD, FF_NOKEEPDELETED, FF_DOWNLOADSINGLE 
 import gtk
 import time, datetime
 from math import floor
@@ -46,40 +46,16 @@ class FeedPropertiesDialog(gtk.Dialog):
 		self._old_flags = 0
 		
 		self._feed_id=0
-		
-		if utils.RUNNING_HILDON:
-			self._hildon_inited = False
 				
 	def show(self):
 		if utils.RUNNING_HILDON:
-			if not self._hildon_inited:
-				#put in a scrolled viewport so the user can see all the prefs
-				parent = self._xml.get_widget('tab1_container')
-				contents = self._xml.get_widget('tab1_contents')
-				scrolled = gtk.ScrolledWindow()
-				scrolled.set_size_request(650, 200)
-				scrolled.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-				viewport = gtk.Viewport()
-				contents.reparent(viewport)
-				scrolled.add(viewport)
-				parent.add(scrolled)
-				
-				parent = self._xml.get_widget('tab2_container')
-				contents = self._xml.get_widget('tab2_contents')
-				scrolled = gtk.ScrolledWindow()
-				scrolled.set_size_request(650, 200)
-				scrolled.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-				viewport = gtk.Viewport()
-				contents.reparent(viewport)
-				scrolled.add(viewport)
-				parent.add(scrolled)
-				self._hildon_inited = True
+			self.resize(600,200)
 			self.show_all()
 		self.set_transient_for(self._app.main_window.get_parent())
 		self._xml.get_widget('notebook1').set_current_page(0)
 		if not utils.HAS_SEARCH:
 			self._xml.get_widget('b_search').hide()
-		if utils.RUNNING_SUGAR:
+		if utils.RUNNING_SUGAR or not utils.HAS_STATUS_ICON:
 			self._xml.get_widget('b_notifyupdates').hide()
 		#if not utils.USE_TAGGING
 		#	self._edit_tags_widget.hide()
@@ -167,6 +143,16 @@ class FeedPropertiesDialog(gtk.Dialog):
 			self._xml.get_widget('b_markasread').set_active(True)
 		else:
 			self._xml.get_widget('b_markasread').set_active(False)
+			
+		if flags & FF_NOKEEPDELETED == FF_NOKEEPDELETED:
+			self._xml.get_widget('b_nokeepdeleted').set_active(True)
+		else:
+			self._xml.get_widget('b_nokeepdeleted').set_active(False)
+			
+		if flags & FF_DOWNLOADSINGLE == FF_DOWNLOADSINGLE:
+			self._xml.get_widget('b_downloadsingle').set_active(True)
+		else:
+			self._xml.get_widget('b_downloadsingle').set_active(False)
 
 	def on_window_feed_properties_delete_event(self, widget, event):
 		return self.hide_on_delete()
@@ -217,6 +203,16 @@ class FeedPropertiesDialog(gtk.Dialog):
 				self._cur_flags -= FF_NOAUTOEXPIRE
 				self._app.db.set_flags_for_feed(self._feed_id, self._cur_flags)
 				
+	def on_b_nokeepdeleted_toggled(self, b_nokeepdeleted):
+		if b_nokeepdeleted.get_active():
+			if not self._cur_flags & FF_NOKEEPDELETED == FF_NOKEEPDELETED:
+				self._cur_flags += FF_NOKEEPDELETED
+				self._app.db.set_flags_for_feed(self._feed_id, self._cur_flags)
+		else:
+			if self._cur_flags & FF_NOKEEPDELETED == FF_NOKEEPDELETED:
+				self._cur_flags -= FF_NOKEEPDELETED
+				self._app.db.set_flags_for_feed(self._feed_id, self._cur_flags)
+				
 	def on_b_addnewlines_toggled(self, b_addnewlines):
 		if b_addnewlines.get_active():
 			if not self._cur_flags & FF_ADDNEWLINES == FF_ADDNEWLINES:
@@ -240,6 +236,16 @@ class FeedPropertiesDialog(gtk.Dialog):
 				self._cur_flags -= FF_MARKASREAD
 				self._app.db.set_flags_for_feed(self._feed_id, self._cur_flags)
 				self._app.emit('render-ops-updated')
+				
+	def on_b_downloadsingle_toggled(self, b_downloadsingle):
+		if b_downloadsingle.get_active():
+			if not self._cur_flags & FF_DOWNLOADSINGLE == FF_DOWNLOADSINGLE:
+				self._cur_flags += FF_DOWNLOADSINGLE
+				self._app.db.set_flags_for_feed(self._feed_id, self._cur_flags)
+		else:
+			if self._cur_flags & FF_DOWNLOADSINGLE == FF_DOWNLOADSINGLE:
+				self._cur_flags -= FF_DOWNLOADSINGLE
+				self._app.db.set_flags_for_feed(self._feed_id, self._cur_flags)
 		
 	def on_save_values_activate(self, event):
 		new_title = self._title_widget.get_text()
