@@ -74,11 +74,10 @@ class FilterSelectorDialog(gtk.Dialog):
 			if key[:3] == '_on':
 				self._xml.signal_connect(key, getattr(self, key))
 				
+		self.connect('delete-event', self._on_delete_event)
+				
 		self._pane_position = 0
 		
-		if utils.RUNNING_HILDON:
-			self._hildon_inited = False
-		
 	def set_taglists(self, all_tags, favorite_tags):
 		self._all_tags_model.clear()
 		self._favorites_model.clear()
@@ -106,19 +105,8 @@ class FilterSelectorDialog(gtk.Dialog):
 		
 	def Show(self):
 		if utils.RUNNING_HILDON:
-			if not self._hildon_inited:
-				#put in a scrolled viewport so the user can see all the prefs
-				parent = self._xml.get_widget('container')
-				contents = self._xml.get_widget('contents')
-				scrolled = gtk.ScrolledWindow()
-				scrolled.set_size_request(650, 200)
-				scrolled.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-				viewport = gtk.Viewport()
-				contents.reparent(viewport)
-				scrolled.add(viewport)
-				parent.add(scrolled)
-				self._hildon_inited = True
 			self._all_tags_treeview.set_property('height-request', 150)
+			self.resize(650,300)
 	
 		context = self.create_pango_context()
 		style = self.get_style().copy()
@@ -142,7 +130,8 @@ class FilterSelectorDialog(gtk.Dialog):
 		self._pane_position = pango.PIXELS((widest_left+10)*char_width)
 		self._window_width  = pango.PIXELS((widest_left+widest_right+10)*char_width)+100
 		
-		self.resize(self._window_width,1)
+		if not utils.RUNNING_HILDON:
+			self.resize(self._window_width,1)
 		self._pane.set_position(self._pane_position)
 		self._favorites_treeview.columns_autosize()
 		self._all_tags_treeview.columns_autosize()
@@ -152,7 +141,6 @@ class FilterSelectorDialog(gtk.Dialog):
 		self.show_all()
 		
 		if utils.RUNNING_HILDON:
-			self._xml.get_widget('info_icon').hide()
 			self._pane_position = 250
 			self._pane.set_position(self._pane_position)
 		
@@ -171,8 +159,24 @@ class FilterSelectorDialog(gtk.Dialog):
 		self.Hide()
 		#self.destroy()
 		
-	#def _on_dialog_tag_favorites_delete_event(self, widget, event):
-	#	return widget.hide_on_delete()
+	def _on_help_button_activate(self, event):
+ 		dialog = gtk.Dialog(title=_("Tag Favorites Help"), parent=None, flags=gtk.DIALOG_MODAL, buttons=(gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+		hbox = gtk.HBox()
+		hbox.set_spacing(12)
+		image = gtk.image_new_from_stock(gtk.STOCK_DIALOG_INFO, gtk.ICON_SIZE_DIALOG)
+		hbox.pack_start(image, False, False, 12)
+		label = gtk.Label(_("""You can drag tags from the righthand side to the favorites list on the left.  To remove a favorite, drag it from the lefthand side back to the right."""))
+		label.set_line_wrap(True)
+		hbox.pack_start(label, True, True, 0)
+		dialog.vbox.pack_start(hbox, True, True, 0)
+		dialog.show_all()
+		dialog.resize(400,-1)
+		response = dialog.run()
+		dialog.hide()
+		del dialog
+
+	def _on_delete_event(self, widget, event):
+		return self.hide_on_delete()
 		
 	def _on_drag_data_get(self, treeview, drag_context, selection_data, info, time):
 		selection = treeview.get_selection()
