@@ -9,6 +9,7 @@ import pickle
 import urllib
 import getopt
 from math import ceil, floor
+import time
 
 import pygst
 pygst.require("0.10")
@@ -53,7 +54,7 @@ class GStreamerPlayer(gobject.GObject):
                            ([])),
         'item-queued': (gobject.SIGNAL_RUN_LAST, 
         				gobject.TYPE_NONE, 
-        				[str, str, gobject.TYPE_PYOBJECT]),
+        				[str, str, gobject.TYPE_PYOBJECT, gobject.TYPE_PYOBJECT]),
         'item-not-supported': (gobject.SIGNAL_RUN_LAST, 
         					   gobject.TYPE_NONE, 
         					   [str, str, gobject.TYPE_PYOBJECT]),
@@ -77,7 +78,9 @@ class GStreamerPlayer(gobject.GObject):
 		self._prepare_save = False
 		self._do_stop_resume = False
 		self._has_video = False
-		self._using_playbin2 = True
+		#self._using_playbin2 = True
+		#TODO: wait until playbin2 isn't buggy, then reenable
+		self._using_playbin2 = False
 		
 		self._error_dialog = GStreamerErrorDialog()
 		
@@ -114,7 +117,7 @@ class GStreamerPlayer(gobject.GObject):
 		if RUNNING_HILDON:
 			hildon.hildon_helper_set_thumb_scrollbar(s_w, True)
 		self._queue_listview = gtk.TreeView()
-		model = gtk.ListStore(str, str, str, gobject.TYPE_PYOBJECT) #uri, title to display, current track indicator, user data
+		model = gtk.ListStore(str, str, str, gobject.TYPE_PYOBJECT, gobject.TYPE_PYOBJECT) #uri, title to display, current track indicator, current pos, user data
 		self._queue_listview.set_model(model)
 		
 		column = gtk.TreeViewColumn(_(""))
@@ -170,7 +173,7 @@ class GStreamerPlayer(gobject.GObject):
 		if not RUNNING_HILDON:
 			image = gtk.Image()
 			image.set_from_stock("gtk-media-previous",gtk.ICON_SIZE_BUTTON)
-			button = gtk.Button("")
+			button = gtk.Button()
 			button.set_image(image)
 		else:
 			button = gtk.Button()
@@ -185,7 +188,7 @@ class GStreamerPlayer(gobject.GObject):
 		if not RUNNING_HILDON:
 			image = gtk.Image()
 			image.set_from_stock("gtk-media-rewind",gtk.ICON_SIZE_BUTTON)
-			button = gtk.Button("")
+			button = gtk.Button()
 			button.set_image(image)
 		else:
 			button = gtk.Button(_("Rew"))
@@ -196,7 +199,7 @@ class GStreamerPlayer(gobject.GObject):
 		if not RUNNING_HILDON:
 			image = gtk.Image()
 			image.set_from_stock("gtk-media-play",gtk.ICON_SIZE_BUTTON)
-			self._play_pause_button = gtk.Button("")
+			self._play_pause_button = gtk.Button()
 			self._play_pause_button.set_image(image)
 		else:
 			self._play_pause_button = gtk.Button(_("Play"))
@@ -207,7 +210,7 @@ class GStreamerPlayer(gobject.GObject):
 		if not RUNNING_HILDON:
 			image = gtk.Image()
 			image.set_from_stock("gtk-media-stop",gtk.ICON_SIZE_BUTTON)
-			button = gtk.Button("")
+			button = gtk.Button()
 			button.set_image(image)
 		else:
 			button = gtk.Button(_("Stop"))
@@ -218,7 +221,7 @@ class GStreamerPlayer(gobject.GObject):
 		if not RUNNING_HILDON:
 			image = gtk.Image()
 			image.set_from_stock("gtk-media-forward",gtk.ICON_SIZE_BUTTON)
-			button = gtk.Button("")
+			button = gtk.Button()
 			button.set_image(image)
 		else:
 			button = gtk.Button(_("FF"))
@@ -229,7 +232,7 @@ class GStreamerPlayer(gobject.GObject):
 		if not RUNNING_HILDON:
 			image = gtk.Image()
 			image.set_from_stock("gtk-media-next",gtk.ICON_SIZE_BUTTON)
-			button = gtk.Button("")
+			button = gtk.Button()
 			button.set_image(image)
 		else:
 			button = gtk.Button(_("Next"))
@@ -310,40 +313,43 @@ class GStreamerPlayer(gobject.GObject):
 			print "error reading playlist"
 			return
 			
-		self._current_index = pickle.load(playlist)
-		self._last_index = -1
-		self._media_position = pickle.load(playlist)
-		self._media_duration = pickle.load(playlist)
-		l = pickle.load(playlist)
-		model = self._queue_listview.get_model()
-		for uri, name, userdata in l:
-			model.append([uri, name, "", userdata])
-			filename = gst.uri_get_location(uri)
-			self.emit('item-queued', filename, name, userdata)
-		if self.__is_exposed:
-			if not self._seek_to_saved_position():
-				#retry once
-				self._seek_to_saved_position()
+		try:
+			self._current_index = pickle.load(playlist)
+			self._last_index = -1
+			self._media_position = pickle.load(playlist)
+			self._media_duration = pickle.load(playlist)
+			l = pickle.load(playlist)
+			model = self._queue_listview.get_model()
+			for uri, name, pos, userdata in l:
+				model.append([uri, name, "", pos, userdata])
+				filename = gst.uri_get_location(uri)
+				self.emit('item-queued', filename, name, pos, userdata)
+			if self.__is_exposed:
+				if not self._seek_in_ready(self._media_position):
+					#retry once
+					self._seek_in_ready(self._media_position)
+		except ValueError, e:
+			logging.warning("Playlist has incorrect format, unable to load")
 		playlist.close()
 		
 	def save(self):
 		"""saves playlist"""
 		try:
 			playlist = open(self._playlist_name, 'w')
-		except:
-			print "error writing playlist"
+		except Exception, e:
+			print "error writing playlist: %s" % str(e)
 			return
 			
 		pickle.dump(self._current_index, playlist)
 		pickle.dump(self._media_position, playlist)
 		pickle.dump(self._media_duration, playlist)
 		l = []
-		for uri, name, current, userdata in self._queue_listview.get_model():
-			l.append([uri, name, userdata])
+		for uri, name, current, pos, userdata in self._queue_listview.get_model():
+			l.append([uri, name, pos, userdata])
 		pickle.dump(l, playlist)
 		playlist.close()
 		
-	def queue_file(self, filename, name=None, userdata=None):
+	def queue_file(self, filename, name=None, pos=0, userdata=None):
 		try:
 			os.stat(filename)
 		except:
@@ -362,11 +368,11 @@ class GStreamerPlayer(gobject.GObject):
 			except:
 				pass
 				
-			self._on_type_discovered(None, ext in known_good, filename, name, userdata)
+			self._on_type_discovered(None, ext in known_good, filename, name, pos, userdata)
 		else:
 			#thanks gstfile.py
 			d = Discoverer(filename)
-			d.connect('discovered', self._on_type_discovered, filename, name, userdata)
+			d.connect('discovered', self._on_type_discovered, filename, name, pos, userdata)
 			d.discover()
 			
 	def unqueue(self, filename=None, userdata=None):
@@ -427,12 +433,12 @@ class GStreamerPlayer(gobject.GObject):
 		else:
 			self.play()
 		
-	def play(self, notick=False):
+	def play(self, notick=False, doseek=False):
 		model = self._queue_listview.get_model()
 		if len(model) == 0:
 			return
 		if self._current_index < 0: self._current_index = 0
-		uri, title, current, userdata = list(model[self._current_index])
+		uri, title, current, pos, userdata = list(model[self._current_index])
 		if self._last_index != self._current_index:
 			self._last_index = self._current_index
 			selection = self._queue_listview.get_selection()
@@ -447,11 +453,13 @@ class GStreamerPlayer(gobject.GObject):
 				return
 			self._prepare_display()
 			self._prepare_save = True
+			if doseek:
+				self._seek_in_ready(pos)
 		else:
 			if self._do_stop_resume:
 				self._do_stop_resume = False
 				self._prepare_display()
-				if not self._seek_to_saved_position():
+				if not self._seek_in_ready(self._media_position):
 					#gstreamer error, recall ourselves
 					self.play()
 					return
@@ -503,9 +511,6 @@ class GStreamerPlayer(gobject.GObject):
 			#release the xv port
 			self._pipeline.unlink(self._v_sink)
 			self._v_sink.set_state(gst.STATE_NULL)
-			if not RUNNING_HILDON:
-				self._v_sink = self._get_video_sink(True)
-				self._pipeline.set_property('video-sink',self._v_sink)
 		self.emit('paused')
 			
 	def ff(self):
@@ -538,21 +543,24 @@ class GStreamerPlayer(gobject.GObject):
 		self._seek_scale.set_range(0,1)
 		self._seek_scale.set_value(0)
 		self._do_stop_resume = False
-		self.play()
+		self.play(doseek=True)
 		
 	def prev(self):
-		selection = self._queue_listview.get_selection()
-		self._pipeline.set_state(gst.STATE_READY)
-		self._current_index -= 1
-		if self._current_index <= 0:
-			self._current_index = 0
+		if (self._media_position > 5 * gst.SECOND):
 			self.seek(0)
-		selection.unselect_all()
-		selection.select_path((self._current_index,))
-		self._seek_scale.set_range(0,1)
-		self._seek_scale.set_value(0)
-		self._do_stop_resume = False
-		self.play()
+		else:
+			selection = self._queue_listview.get_selection()
+			self._pipeline.set_state(gst.STATE_READY)
+			self._current_index -= 1
+			if self._current_index <= 0:
+				self._current_index = 0
+				self.seek(0)
+			selection.unselect_all()
+			selection.select_path((self._current_index,))
+			self._seek_scale.set_range(0,1)
+			self._seek_scale.set_value(0)
+			self._do_stop_resume = False
+			self.play(doseek=True)
 		
 	def finish(self):
 		self.save()
@@ -586,8 +594,10 @@ class GStreamerPlayer(gobject.GObject):
 		if message.type == gst.MESSAGE_EOS:
 			model = self._queue_listview.get_model()
 			if self._current_index < len(model) - 1:
+				self._update_position(0)
 				self.next()
 			else:
+				self._update_position(0)
 				self.stop()
 		elif message.type == gst.MESSAGE_ERROR:
 			gerror, debug = message.parse_error()
@@ -613,14 +623,14 @@ class GStreamerPlayer(gobject.GObject):
 	
 	def _on_prev_clicked(self, b): self.prev()
 	
-	def _on_type_discovered(self, discoverer, ismedia, filename, name, userdata):
+	def _on_type_discovered(self, discoverer, ismedia, filename, name, pos, userdata):
 		if ismedia:
 			model = self._queue_listview.get_model()
-			uri = 'file://'+urllib.quote(filename)
+			uri = 'file://'+urllib.quote(str(filename))
 			if RUNNING_SUGAR or RUNNING_HILDON:
 				name = '<span size="x-small">'+name+'</span>'
-			model.append([uri, name, "", userdata])
-			self.emit('item-queued', filename, name, userdata)
+			model.append([uri, name, "", pos, userdata])
+			self.emit('item-queued', filename, name, pos, userdata)
 			self.save()
 		else:
 			self.emit('item-not-supported', filename, name, userdata)
@@ -635,7 +645,6 @@ class GStreamerPlayer(gobject.GObject):
 		
 		for i in iter_list:
 			if model.get_path(i)[0] == self._current_index:
-				print "stopping current"
 				self.stop()
 			model.remove(i)
 			
@@ -665,10 +674,10 @@ class GStreamerPlayer(gobject.GObject):
 		self.seek(pos)
 		
 	def _on_queue_row_activated(self, treeview, path, view_column):
-		self.stop()
+		self.pause()
 		self._last_index = -1
 		self._current_index = path[0]
-		self.play()
+		self.play(doseek=True)
 		
 	def _on_queue_row_button_press(self, widget, event):
 		if event.button==3: #right click     
@@ -718,9 +727,9 @@ class GStreamerPlayer(gobject.GObject):
 			model = self._queue_listview.get_model()
 			if len(model) > 0:
 				#self._prepare_display()
-				if not self._seek_to_saved_position():
+				if not self._seek_in_ready(self._media_position):
 					#retry once
-					self._seek_to_saved_position()
+					self._seek_in_ready(self._media_position)
 			self.__is_exposed = True
 				
 	###utility functions###
@@ -866,7 +875,7 @@ class GStreamerPlayer(gobject.GObject):
 				
 			gobject.idle_add(pop_trap)
 
-	def _seek_to_saved_position(self):
+	def _seek_in_ready(self, new_pos):
 		"""many sources don't support seek in ready, so we do it the old fashioned way:
 		play, wait for it to play, pause, wait for it to pause, and then seek"""
 		model = self._queue_listview.get_model()
@@ -875,8 +884,8 @@ class GStreamerPlayer(gobject.GObject):
 			i+=1
 			if i == self._current_index: row[2] = "&#8226;" #bullet
 			else: row[2] = ""
-		#save, because they may get overwritten when we play and pause
-		pos, dur = self._media_position, self._media_duration
+		#save, because it may get overwritten when we play and pause
+		dur = self._media_duration
 		if not RUNNING_HILDON:
 			volume = self._pipeline.get_property('volume')
 		#temporarily mute to avoid little bloops during this hack
@@ -890,13 +899,16 @@ class GStreamerPlayer(gobject.GObject):
 		self.play(True)
 		change_return, state, pending = self._pipeline.get_state(gst.SECOND * 10)
 		if change_return != gst.STATE_CHANGE_SUCCESS:
-			print "some problem changing state to play, may be playbin2 issue?"
+			print "some problem changing state to play (bad uri? playbin2?)"
 			self._using_playbin2 = False
 			self.stop()
 			self._pipeline.set_state(gst.STATE_NULL)
 			self.gstreamer_init()
 			self._last_index = -1 #trigger play() to reinit the pipe
 			return False
+
+		dur = self._pipeline.query_duration(gst.FORMAT_TIME)[0]
+				
 		self.pause()
 		if change_return != gst.STATE_CHANGE_SUCCESS:
 			print "some problem changing state to pause"
@@ -905,8 +917,9 @@ class GStreamerPlayer(gobject.GObject):
 			self.gstreamer_init()
 			self._last_index = -1 #trigger play() to reinit the pipe
 			return False
-		self._media_position, self._media_duration = pos, dur
-		self.seek(self._media_position)
+		
+		self._media_position, self._media_duration = new_pos, dur
+		self.seek(new_pos)
 		if self._media_duration <= 0:
 			self._media_duration = 1
 		self._resize_pane()
@@ -940,6 +953,7 @@ class GStreamerPlayer(gobject.GObject):
 		
 		self._update_seek_bar()
 		self._update_time_label()
+		self._update_position()
 		if self._prepare_save:
 			self._prepare_save = False
 			self.save()
@@ -974,6 +988,12 @@ class GStreamerPlayer(gobject.GObject):
 			
 		self._time_label.set_text(nano_to_string(self._media_position)+" / "+nano_to_string(self._media_duration))
 		
+	def _update_position(self, pos=None):
+		if pos is None:
+			pos = self._media_position
+		model = self._queue_listview.get_model()
+		model[self._current_index][3] = pos
+		
 	#def _on_sync_message(self, bus, message):
 	#	if message.structure is None:
 	#		return
@@ -982,7 +1002,7 @@ class GStreamerPlayer(gobject.GObject):
 	#		message.src.set_property('force-aspect-ratio', True)
 	###drag and drop###
 		
-	def _on_queue_drag_data_received(self, treeview, context, x, y, selection, targetType, time):
+	def _on_queue_drag_data_received(self, treeview, context, x, y, selection, targetType, thyme):
 		if targetType == self._TARGET_TYPE_REORDER:
 			treeview.emit_stop_by_name('drag-data-received')
 			model, paths_to_copy = treeview.get_selection().get_selected_rows()
@@ -999,7 +1019,7 @@ class GStreamerPlayer(gobject.GObject):
 				
 				if self.checkSanity(model, iter_to_copy, target_iter):
 					self.iterCopy(model, target_iter, row, pos)
-					context.finish(True, True, time) #finishes the move
+					context.finish(True, True, thyme) #finishes the move
 					i=-1
 					for row in model:
 						i+=1
@@ -1009,16 +1029,16 @@ class GStreamerPlayer(gobject.GObject):
 						else:
 							row[2]=""							
 				else:
-					context.finish(False, False, time)
+					context.finish(False, False, thyme)
 			except:
 				model.append(row)
-				context.finish(True, True, time)
+				context.finish(True, True, thyme)
 		elif targetType == self._TARGET_TYPE_URI_LIST:
 			uri_list = [s for s in selection.data.split('\r\n') if len(s) > 0]
 			for uri in uri_list:
 				uri = uri.replace("file://", "")
 				uri = urllib.unquote(uri)
-				self.queue_file(uri)			
+				self.queue_file(uri)
 
 	def checkSanity(self, model, iter_to_copy, target_iter):
 		path_of_iter_to_copy = model.get_path(iter_to_copy)
@@ -1110,12 +1130,13 @@ if __name__ == '__main__': # Here starts the dynamic part of the program
 	else:
 		home = os.path.join(os.getenv('HOME'), ".penguintv")
 	try:
-		opts, args = getopt.getopt(sys.argv[1:], "p:", ["--playlist"])
+		opts, args = getopt.getopt(sys.argv[1:], "p:", ["playlist="])
 	except getopt.GetoptError, e:
-		print "error %s", str(e)
+		print "error %s" % str(e)
 		sys.exit(1)
 	playlist = os.path.join(home, 'gst_playlist.pickle')
 	if len(opts) > 0:
+		print opts
 		for o, a in opts:
 			if o in ('-p', '--playlist'):
 				playlist = a
