@@ -53,7 +53,7 @@ class HTTPDownloader(Downloader):
 			curl.setopt(pycurl.FOLLOWLOCATION, 1)
 			curl.setopt(pycurl.MAXREDIRS, 5)
 			curl.setopt(pycurl.CONNECTTIMEOUT, 30)
-			curl.setopt(pycurl.NOSIGNAL, 1)
+			curl.setopt(pycurl.NOSIGNAL, 1) #makes downloading thread-safe
 			curl.setopt(pycurl.WRITEDATA, fp)
 			curl.setopt(pycurl.PROGRESSFUNCTION, self._wrap_progress_callback)
 			curl.setopt(pycurl.NOPROGRESS, 0)
@@ -67,11 +67,23 @@ class HTTPDownloader(Downloader):
 			fp.close()
 			if self.media['url'][:5] == "http:":
 				if response != 200 and response != 206:
+					logging.warning("HTTP download error: %s %s" % (self.media['url'],response))
 					if response == 404:
-						self.media['errormsg']=_("404: File Not Found")
+						self.media['errormsg']=_("404: File Not Found: %s" % self.media['url'])
+					elif response == 400:
+						#maybe not properly escaped url?
+						import urlparse, urllib
+						p = urlparse.urlparse(self.media['url'])
+						new_p = (p[0], urllib.quote(p[1]), urllib.quote(p[2]),
+							urllib.quote(p[3]), urllib.quote(p[4]), urllib.quote(p[5]))
+						new_url = urlparse.urlunparse(new_p)
+						self.media['url'] = new_url
+						self.download(None)
+						return
 					else:
-						d = {"response":response}
-						self.media['errormsg']=_("Some HTTP error: %(response)s") % d
+						d = {"response":response,
+							 "url":self.media['url']}
+						self.media['errormsg']=_("Some HTTP error: %(response)s %(url)s") % d
 					self.status = FAILURE
 					self.message = self.media['errormsg']
 					self._finished_callback()
@@ -83,13 +95,15 @@ class HTTPDownloader(Downloader):
 				if major_code == 2: #positive reply
 					pass
 				elif major_code == 4 or major_code == 5:
-					d = {"response":response}
-					self.media['errormsg']=_("FTP error: %(response)s") % d
+					d = {"response":response,
+					 	 "url":self.media['url']}
+					self.media['errormsg']=_("FTP error: %(response)s %(url)s") % d
 				else:
-					d = {"response":response}
-					self.media['errormsg']=_("Unexpected FTP response: %(response)s") % d
+					d = {"response":response,
+						 "url":self.media['url']}
+					self.media['errormsg']=_("Unexpected FTP response: %(response)s %(url)s") % d
 			else: 
-				self.media['errormsg']=_("Unknown protocol")
+				self.media['errormsg']=_("Unknown protocol for url %s" % self.media['url'])
 				self.status = FAILURE
 				self.message = self.media['errormsg']
 				self._finished_callback()
@@ -113,7 +127,7 @@ class HTTPDownloader(Downloader):
 				self.message = ""
 				self._finished_callback()
 			else:
-				print "some downloading error "+str(data),self.media
+				logging.warning("some downloading error %s %s" % (str(data),self.media))
 				self.media['errormsg']=data
 				self.status = FAILURE
 				self.message = data
