@@ -2,13 +2,15 @@ import gtk
 import gtk.glade
 import gobject
 import sys, os, os.path
-import sets
 import logging
+try:
+	set
+except:
+	from sets import Set as set
 
 import ptvDB
 import penguintv
 import Player
-import UpdateTasksManager
 import utils
 import Downloader
 #from trayicon.SonataNotification import TrayIconTips as tooltips
@@ -70,7 +72,7 @@ class MainWindow(gobject.GObject):
 						   ([]))
 	}
 
-	def __init__(self, app, use_internal_player=False, window=None, status_icon=None):
+	def __init__(self, app, use_internal_player=False, window=None, status_icon=None, playlist=None):
 		gobject.GObject.__init__(self)
 		self._app = app
 		self._window_inited = False
@@ -86,7 +88,10 @@ class MainWindow(gobject.GObject):
 		self._state = S_DEFAULT
 		self._fullscreen = False
 		self._fullscreen_lock = False
-		
+		if playlist is None:
+			self._playlist_filename = os.path.join(utils.get_home(), "gst_playlist.pickle")
+		else:
+			self._playlist_filename = playlist
 		self._use_internal_player = False
 		if utils.HAS_GSTREAMER and use_internal_player:
 			self._use_internal_player = True
@@ -315,6 +320,41 @@ class MainWindow(gobject.GObject):
 				self._widgetTree.get_widget('show_notifications').hide()
 			self.window = self.app_window
 			
+		if self._use_internal_player:
+			#From Sonata/dbus_plugin.py
+			if utils.HAS_DBUS:
+				import dbus
+				try:
+					bus = dbus.SessionBus()
+					dbusObj = bus.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus')
+					dbusInterface = dbus.Interface(dbusObj, 'org.freedesktop.DBus')
+					if dbusInterface.NameHasOwner('org.gnome.SettingsDaemon'):
+						try:
+							# mmkeys for gnome 2.22+
+							settingsDaemonObj = bus.get_object('org.gnome.SettingsDaemon', '/org/gnome/SettingsDaemon/MediaKeys')
+							settingsDaemonInterface = dbus.Interface(settingsDaemonObj, 'org.gnome.SettingsDaemon.MediaKeys')
+							settingsDaemonInterface.GrabMediaPlayerKeys('PenguinTV', 0)
+						except:
+							# mmkeys for gnome 2.18+
+							settingsDaemonObj = bus.get_object('org.gnome.SettingsDaemon', '/org/gnome/SettingsDaemon')
+							settingsDaemonInterface = dbus.Interface(settingsDaemonObj, 'org.gnome.SettingsDaemon')
+							settingsDaemonInterface.GrabMediaPlayerKeys('PenguinTV', 0)
+						settingsDaemonInterface.connect_to_signal('MediaPlayerKeyPressed', lambda app, key:self._dbus_mmkeys_cb(app, key))
+				except:
+					pass
+			else:
+				try:
+					import mmkeys
+					keys = mmkeys.MmKeys()
+			
+					keys.connect("mm_prev", lambda x,y: self._gstreamer_player.prev())
+					keys.connect("mm_next", lambda x,y: self._gstreamer_player.next())
+					keys.connect("mm_playpause", lambda x,y: self._gstreamer_player.play_pause_toggle())
+					keys.connect("mm_stop", lambda x,y: self._gstreamer_player.stop())
+				except:
+					logging.debug("Multimedia Key Support not found")
+				
+			
 		self._notebook.show_only(N_FEEDS)
 		if not utils.HAS_SEARCH:
 			self.search_container.hide_all()
@@ -334,6 +374,12 @@ class MainWindow(gobject.GObject):
 			
 		return False
 		
+	def _dbus_mmkeys_cb(self, app, key):
+		if app == 'PenguinTV':
+			if key in ("Play", "PlayPause", "Pause"):
+				key = "PlayPause"
+			self._app.player.control_internal(key)
+		
 	def _build_hildon_menu(self, widgets):
 		menu = gtk.Menu()  
 		
@@ -585,7 +631,7 @@ class MainWindow(gobject.GObject):
 		
 		p_vbox = gtk.VBox()
 		if self._use_internal_player:
-			self._gstreamer_player = GStreamerPlayer.GStreamerPlayer(p_vbox, os.path.join(utils.get_home(), "gst_playlist.pickle"), tick_interval=5)
+			self._gstreamer_player = GStreamerPlayer.GStreamerPlayer(p_vbox, self._playlist_filename, tick_interval=5)
 			self._gstreamer_player.connect('item-queued', self._on_player_item_queued)
 			self._gstreamer_player.connect('items-removed', self._on_player_items_removed)
 			self._gstreamer_player.Show()
@@ -699,24 +745,19 @@ class MainWindow(gobject.GObject):
 										  str,		#filter name
 										  int,      #seperator
 										  bool)     #visible
+		
+		eventbox = components.get_widget('filter_selector_eventbox')
+		self._filter_selector_combo = gtk.ComboBox(self._filter_tree)
+		cell = gtk.CellRendererText()
 		if utils.RUNNING_HILDON:
-			eventbox = components.get_widget('filter_selector_eventbox')
-			self._filter_selector_combo = gtk.ComboBox(self._filter_tree)
-			cell = gtk.CellRendererText()
 			cell.set_property("size-points", 24)
-			self._filter_selector_combo.pack_start(cell, True)
-			self._filter_selector_combo.add_attribute(cell, 'text', 0)
-			self._filter_selector_combo.connect('changed', self.on_filter_changed)
-			eventbox.add(self._filter_selector_combo)
-		else:
-			self._filter_selector_combo = components.get_widget('filter_selector_combo')
-		
-										  
-		filter_filter = self._filter_tree.filter_new()
-		filter_filter.set_visible_column(3)
-		
-		#if not utils.RUNNING_HILDON:								  
-		self._filter_selector_combo.set_model(filter_filter)
+		self._filter_selector_combo.pack_start(cell, True)
+		self._filter_selector_combo.add_attribute(cell, 'text', 0)
+		self._filter_selector_combo.add_attribute(cell, 'sensitive', 3)
+		self._filter_selector_combo.connect('changed', self.on_filter_changed)
+		eventbox.add(self._filter_selector_combo)
+
+		self._filter_selector_combo.set_model(self._filter_tree)
 		self._filter_selector_combo.set_row_separator_func(lambda model,iter:model[iter][2]==1)
 		
 		self._filters = [] #text, text to display, type, tree path
@@ -1147,8 +1188,6 @@ class MainWindow(gobject.GObject):
 			else:
 				self._filter_tree[FeedList.NOTIFY][3] = False
 
-			model.refilter()
-
 		self._activate_filter()
 		
 	def _find_path(self, index):
@@ -1180,8 +1219,6 @@ class MainWindow(gobject.GObject):
 		else:
 			self._filter_tree[FeedList.NOTIFY][3] = False
 			
-		model.refilter()
-
 		self._find_path(index)
 		it = model.get_iter(self._active_filter_path)
 		self._filter_selector_combo.set_active_iter(it)
@@ -1227,7 +1264,7 @@ class MainWindow(gobject.GObject):
 		#if event.state & gtk.gdk.CONTROL_MASK:
 		#	if keyname == 'k':
 		#		self.search_entry.grab_focus()
-
+		
 		if event.state & gtk.gdk.MOD1_MASK:
 			if keyname == '1':
 				self._notebook.set_current_page(N_FEEDS)
@@ -1282,6 +1319,10 @@ class MainWindow(gobject.GObject):
 					#emission
 					if self._gstreamer_player.handle_key(keyname):
 						widget.stop_emission("key-press-event")
+					if keyname == "F" and event.state & gtk.gdk.CONTROL_MASK:
+						self._gstreamer_player.ff()
+					elif keyname == "B" and event.state & gtk.gdk.CONTROL_MASK:
+						self._gstreamer_player.rew()
 			
 	def on_mark_entry_as_viewed_activate(self,event):
 		entry = self.entry_list_view.get_selected()
@@ -1341,7 +1382,7 @@ class MainWindow(gobject.GObject):
 	def on_play_unviewed_clicked(self, event):
 		self._app.play_unviewed()
 		
-	def _on_player_item_queued(self, player, filename, name, userdata):
+	def _on_player_item_queued(self, player, filename, name, pos, userdata):
 		self._notebook.show_page(N_PLAYER)
 		self.emit('player-show')	
 		#if player.get_queue_count() == 1:
@@ -1382,7 +1423,7 @@ class MainWindow(gobject.GObject):
 		self._app.refresh_feed(feed)
 		
 	def on_refresh_feeds_activate(self, event):
-		self._app.poll_feeds()
+		self._app.poll_feeds(ptvDB.A_ALL_FEEDS)
 
 	def on_refresh_feeds_with_errors_activate(self, event):
 		self._app.poll_feeds(ptvDB.A_ERROR_FEEDS)
@@ -1618,6 +1659,7 @@ class MainWindow(gobject.GObject):
 		self._filters = []
 		self._favorite_filters = []
 		self._filter_tree.clear()
+		
 		completion_model = self.search_entry.get_completion().get_model()
 		completion_model.clear()
 				
@@ -1690,7 +1732,7 @@ class MainWindow(gobject.GObject):
 		
 		if not utils.RUNNING_HILDON:	
 			self._filter_tree.append(None, [_('Edit Favorite Tags...'), _('Edit Favorite Tags...'), 2, True])
-		
+			
 		#get index for our previously selected tag
 		index = self.get_filter_index(current_filter)
 		if not self.changing_layout:
@@ -1717,8 +1759,8 @@ class MainWindow(gobject.GObject):
 			i+=1
 			self._app.db.set_tag_favorite(t, i)
 				
-		old = sets.Set(old_order)
-		new = sets.Set(tag_list)
+		old = set(old_order)
+		new = set(tag_list)
 		removed = list(old.difference(new))
 		for t in removed:
 			self._app.db.set_tag_favorite(t, 0)
