@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.5
+#!/usr/bin/env python
 #Out-of-process poller for PenguinTV
 #returns data over dbus
 
@@ -19,6 +19,8 @@ if RUNNING_HILDON:
 else:
 	socket.setdefaulttimeout(10.0)
 
+#logging.basicConfig(level=logging.DEBUG)
+
 #try:
 #	import tempfile
 #	logfile = tempfile.mkstemp(prefix='poller-',suffix='.log')[1]
@@ -28,13 +30,13 @@ else:
 
 import dbus
 import dbus.service
-from dbus.mainloop.glib import DBusGMainLoop
+import dbus.mainloop.glib
 import gobject
 
-	
 import ptvDB
 
-DBusGMainLoop(set_as_default=True)
+dbus.mainloop.glib.threads_init()
+dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
 
 class Poller(dbus.service.Object):
 	def __init__(self, remote_app, mainloop, bus, object_path="/PtvPoller"):
@@ -51,6 +53,7 @@ class Poller(dbus.service.Object):
 		
 	def _app_ping(self):
 		try:
+			#logging.debug("ping")
 			if not self._remote_app.Ping():
 				logging.debug("Poller exit, ping was false (app exiting)")
 				self.exit()
@@ -60,15 +63,21 @@ class Poller(dbus.service.Object):
 		return True
 		
 	def _polling_cb(self, args, cancelled=False):
-		logging.debug("Poller calling back, %s" % str(self._quitting))
+		logging.debug("Poller calling back, %s" % (str(self._quitting)))
+		#def go(args, cancelled):
 		try:
+			#logging.debug("tick1")
 			if not self._remote_app.PollingCallback(str(args), cancelled):
+				##logging.debug("tick2")
 				logging.debug("Poller exit, negative callback (exiting)")
 				self.exit()
+			return False
 		except Exception, e:
 			logging.debug("Poller exit, exception in callback: %s" % str(e))
 			self.exit()
-		
+			return False
+		#gobject.timeout_add(100, go, args, cancelled)
+
 	@dbus.service.method("com.ywwg.PenguinTVPoller.PollInterface")
 	def poll_multiple(self, arguments, feeds, finished_cb):
 		logging.debug("Poller starting poll mult")
@@ -91,10 +100,12 @@ class Poller(dbus.service.Object):
 		
 	@dbus.service.method("com.ywwg.PenguinTVPoller.PollInterface")
 	def is_quitting(self):
+		#logging.debug("is quitting?")
 		return self._quitting
 		
 	@dbus.service.method("com.ywwg.PenguinTVPoller.PollInterface")
 	def exit(self):
+		logging.debug("exiting")
 		self._quitting = True
 		self._db.finish(False, False)
 		self._mainloop.quit()
@@ -104,6 +115,11 @@ class Poller(dbus.service.Object):
 	def get_pid(self):
 		return os.getpid()
 		
+	@dbus.service.method("com.ywwg.PenguinTVPoller.PollInterface")
+	def ping(self):
+		logging.debug("responding to ping")
+		return True
+		
 if __name__ == '__main__': # Here starts the dynamic part of the program
 	bus = dbus.SessionBus()
 	dubus = bus.get_object('org.freedesktop.DBus', '/org/freedesktop/dbus')
@@ -116,6 +132,7 @@ if __name__ == '__main__': # Here starts the dynamic part of the program
 		sys.exit(1)
 		
 	bus = dbus.service.BusName("com.ywwg.PenguinTVPoller", bus=bus)
+	
 	loop = gobject.MainLoop()
 	poller = Poller(remote_app, loop, bus)
 	if RUNNING_HILDON:
