@@ -3,7 +3,7 @@ import random
 import logging
 
 class MyTCPServer(SocketServer.ForkingTCPServer):
-	def __init__(self, server_address, RequestHandlerClass):
+	def __init__(self, server_address, RequestHandlerClass, store_location):
 		SocketServer.ForkingTCPServer.__init__(self, server_address, RequestHandlerClass)
 		
 		self._key = ""
@@ -11,10 +11,15 @@ class MyTCPServer(SocketServer.ForkingTCPServer):
 		
 		self._updates = []
 		self._quitting = False
+		self.store_location = store_location
 		
 	def serve_forever(self):
 		while 1:
-			self.handle_request()
+			try:
+				self.handle_request()
+			except Exception, e:
+				logging.error("Error in Ajax Server: %s" % str(e))
+				continue
 			if self._quitting:
 				logging.info('quitting tcp server')
 				return
