@@ -106,28 +106,32 @@ class StatusTrayIcon(gtk.StatusIcon):
 			b = hildon.hildon_banner_show_information_with_markup(self._parent, "NULL", "<b>%s</b>\n%s" % (title, message))
 		if icon is not None:
 			b.set_icon_from_file(icon)
-		b.set_timeout(5000)
+		b.set_timeout(3000)
 		def done_showing():
 			self._notification_displaying = False
 			return False
 		gobject.timeout_add(5000, done_showing)
 			
 	def _display_pynotification(self, title, message, icon=None, userdata=None):
-		self._notification_displaying = True
+		#don't need this, pynotifications can stack up
+		#self._notification_displaying = True
+		#logging.debug("displaying pynotification: %s %s" % (title, message))
 		if icon is not None:
 			notification = pynotify.Notification(title, message, None)
 			notification.set_icon_from_pixbuf(icon)
 		else:
 			notification = pynotify.Notification(title, message, "info")
 	
-		notification.set_timeout(5000)
+		notification.set_timeout(3000)
 		notification.set_data('userdata', userdata)
-		notification.add_action('default', 'Default Action', self.__pynotification_click_cb)
-		notification.connect('closed', self.__notification_closed_cb)
+		#setting a default action used to work, but now it causes the notification to become
+		#a boring OK/Cancel dialog box, which is weird
+		#notification.add_action('default', 'Default Action', self.__pynotification_click_cb)
+		#notification.connect('closed', self.__notification_closed_cb)
 
-		screen, rect, orient = self.get_geometry()
-		notification.set_hint("x", rect.x +(rect.width / 2))
-		notification.set_hint("y", rect.y +(rect.height / 2))
+		#screen, rect, orient = self.get_geometry()
+		#notification.set_hint("x", rect.x +(rect.width / 2))
+		#notification.set_hint("y", rect.y +(rect.height / 2))
 		notification.show()
 		
 	def _display_sonatafication(self, title, message, icon=None, userdata=None):
