@@ -12,7 +12,7 @@ import gettext
 import shutil
 import logging
 
-VERSION="4.0.0"
+VERSION="4.2.0"
 
 try:
 	from sqlite3 import OperationalError as OperationalError
@@ -37,8 +37,6 @@ except:
 	
 
 
-from subprocess import Popen, PIPE, STDOUT
-
 #locale.setlocale(locale.LC_ALL, '')
 gettext.install('penguintv', '/usr/share/locale')
 gettext.bindtextdomain('penguintv', '/usr/share/locale')
@@ -70,6 +68,7 @@ if RUNNING_SUGAR:
 else:
 	if DO_GTK_CHECKS:
 		try:
+			import gtk
 			import gtkmozembed
 			HAS_MOZILLA = True
 		except:
@@ -145,6 +144,12 @@ else:
 		HAS_GSTREAMER = True
 	except:
 		HAS_GSTREAMER = False
+		
+	try:
+		import dbus
+		HAS_DBUS = True
+	except:
+		HAS_DBUS = False
 
 if RUNNING_HILDON:
 	#having a status icon causes tons of problems (causes hildonn UI to crash)
@@ -169,14 +174,14 @@ else:
 	logging.info("xapian or lucene not found, search disabled")
 	
 # Pynotify is still broken, forget it
-HAS_PYNOTIFY = False
+#HAS_PYNOTIFY = False
 #HAS_PYXML = False
 #HAS_STATUS_ICON = False
 #HAS_GNOMEVFS = False
 #HAS_MOZILLA=False
 
 #too buggy, disable for release
-ENABLE_ARTICLESYNC=False
+ENABLE_ARTICLESYNC=True
 
 def get_home():
 	if RUNNING_SUGAR:
@@ -323,9 +328,11 @@ def get_play_command_for(filename):
 		return full_qual_prog+" "+known_players[program]
 	return full_qual_prog
 				
-def get_dated_dir():
-	today = time.strftime("%Y-%m-%d")
-	return today				
+def get_dated_dir(t=None):
+	if t is None:
+		t = time.localtime()
+	today = time.strftime("%Y-%m-%d", t)
+	return today 		
 			
 #http://www.faqts.com/knowledge_base/view.phtml/aid/2682
 class GlobDirectoryWalker:
@@ -404,6 +411,12 @@ def my_quote(s):
 	s=string.replace(s,"&","&amp;")
 	return s
 	
+def make_pathsafe(s):
+	unsafe=('<','>',':','"','/','\\','|')
+	for c in unsafe:
+		s=string.replace(s,c,'_')
+	return s
+	
 def get_hyphen():
 	if RUNNING_HILDON:
 		return "--"
@@ -449,7 +462,7 @@ def desktop_has_file_handler(filename):
 	else:
 		if HAS_GNOMEVFS:
 			# Otherwise, use GNOMEVFS to find the appropriate handler
-			handler = gnomevfs.mime_get_default_application(gnomevfs.get_mime_type(urllib.quote(filename))) #PA fix
+			handler = gnomevfs.mime_get_default_application(gnomevfs.get_mime_type(urllib.quote(str(filename)))) #PA fix #Nerdist fix, urllib prefers strings over unicode
 			if handler is not None:
 				return True
 			return False
@@ -557,9 +570,16 @@ def init_gtkmozembed():
 	"""We need to set up mozilla with set_comp_path in order for it not to 
 	crash.  The fun part is not hardcoding that path since we have no way
 	of getting it from the module itself.  good luck with this"""
-
-	assert HAS_MOZILLA
 	
+	logging.info("initializing mozilla")
+	assert HAS_MOZILLA
+
+	#new, easy behavior
+	if os.path.exists('/usr/lib/xulrunner-1.9'):
+		gtkmozembed.set_comp_path('/usr/lib/xulrunner-1.9')
+		return
+	
+	#old, disgusting behavior
 	if not os.environ.has_key('MOZILLA_FIVE_HOME'):
 		return False
 	moz_path = os.environ['MOZILLA_FIVE_HOME']
@@ -714,42 +734,42 @@ def get_pynotify_ok():
 		logging.info("pynotify too old, using fallback notifications")
 		return False
 
-	# if it's good, check to see it's not lying about prefix
-	cmd = "pkg-config notify-python --variable=prefix"
-	p = subprocess.Popen(cmd, shell=True, close_fds=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-	retval = p.wait()
-	stderr = p.stderr.read()
-	if len(stderr) > 1 or retval != 0:
-		logging.info("trouble getting notify-python prefix from pkg-config, using fallback notifications")
-		return False
-	pkgconfig_prefix = p.stdout.read().strip()
-	
-	try:
-		dirname = os.path.split(pynotify.__file__)[0]
-		f = open(os.path.join(dirname, "_pynotify.la"))
-	except:
-		logging.info("trouble opening _pynotify.la, using fallback notifications")
-		return False
-	
-	libdir_line = ""
-	
-	for line in f.readlines():
-		if line[0:6] == "libdir":
-			libdir_line = line.split("=")[1][1:-1]
-			break
-	f.close()
-	
-	libdir_line = libdir_line.strip()
-	
-	if len(libdir_line) == 0:
-		logging.info("trouble reading _pynotify.la, using fallback notifications")
-		return False
-	
-	if pkgconfig_prefix not in libdir_line:
-		logging.info("pkgconfig does not agree with _pynotify.la, using fallback notifications")
-		return False
-
-	logging.info("Using pynotify notifications")
+#	# if it's good, check to see it's not lying about prefix
+#	cmd = "pkg-config notify-python --variable=prefix"
+#	p = subprocess.Popen(cmd, shell=True, close_fds=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+#	retval = p.wait()
+#	stderr = p.stderr.read()
+#	if len(stderr) > 1 or retval != 0:
+#		logging.info("trouble getting notify-python prefix from pkg-config, using fallback notifications")
+#		return False
+#	pkgconfig_prefix = p.stdout.read().strip()
+#	
+#	try:
+#		dirname = os.path.split(pynotify.__file__)[0]
+#		f = open(os.path.join(dirname, "_pynotify.la"))
+#	except:
+#		logging.info("trouble opening _pynotify.la, using fallback notifications")
+#		return False
+#	
+#	libdir_line = ""
+#	
+#	for line in f.readlines():
+#		if line[0:6] == "libdir":
+#			libdir_line = line.split("=")[1][1:-1]
+#			break
+#	f.close()
+#	
+#	libdir_line = libdir_line.strip()
+#	
+#	if len(libdir_line) == 0:
+#		logging.info("trouble reading _pynotify.la, using fallback notifications")
+#		return False
+#	
+#	if pkgconfig_prefix not in libdir_line:
+#		logging.info("pkgconfig does not agree with _pynotify.la, using fallback notifications")
+#		return False
+#
+#	logging.info("Using pynotify notifications")
 	return True
 
 def db_except(default_retval=None):
